@@ -1,6 +1,8 @@
 from abc import ABC
 
-from tabml import experiment_manager
+import mlflow
+
+from tabml import experiment_manager, model_wrappers
 from tabml.data_loaders import BaseDataLoader
 from tabml.model_analysis import ModelAnalysis
 from tabml.trainers import BaseTrainer
@@ -26,11 +28,15 @@ class BasePipeline(ABC):
             model_wrapper defined by users.
     """
 
-    def __init__(self, path_to_config: str, custom_model_wrapper=None):
+    def __init__(
+        self, path_to_config: str, custom_model_wrapper=None, custom_run_dir=""
+    ):
         logger.info("=" * 80)
         logger.info(f"Running pipeline with config {path_to_config}")
         logger.info("=" * 80)
-        self.exp_manager = experiment_manager.ExperimentManger(path_to_config)
+        self.exp_manager = experiment_manager.ExperimentManger(
+            path_to_config, custom_run_dir=custom_run_dir
+        )
         self.config = parse_pipeline_config_pb(path_to_config)
         self.data_loader = self._get_data_loader()
         assert self.data_loader.label_col is not None, "label_col must be specified"
@@ -41,7 +47,12 @@ class BasePipeline(ABC):
 
     def run(self):
         self.exp_manager.create_new_run_dir()
-        self.train()
+        # start mlflow auto log
+        model_wrappers.MLFLOW_AUTOLOG[self.model_wrapper.mlflow_model_type]
+        with mlflow.start_run():
+            mlflow.log_params(self.model_wrapper.params)
+            self.train()
+            self.analyze_model()
 
     def train(self):
         model_dir = self.exp_manager.run_dir
